.. currentmodule:: wcosmo

.. include:: ../../README.rst

Examples
--------

.. toctree::
   :maxdepth: 2

   Examples <examples/index>

API Reference
-------------

.. toctree::
   :maxdepth: 2

   API <api/index>
